==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AFinalModifier.h <==
// public final class soot.jimple.parser.node.AFinalModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f3c692663a8f388 soot_jimple_parser_node_AFinalModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AFinalModifier_H_
#define _JC_soot_jimple_parser_node_AFinalModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFinal$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$sub_refs	_jc_soot_jimple_parser_node_AFinalModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$refs	_jc_soot_jimple_parser_node_AFinalModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$nonrefs	_jc_soot_jimple_parser_node_AFinalModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$object	_jc_soot_jimple_parser_node_AFinalModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AFinalModifier$vmethods	_jc_soot_jimple_parser_node_AFinalModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFinalModifier$vtable	_jc_soot_jimple_parser_node_AFinalModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFinalModifier$vtype	_jc_soot_jimple_parser_node_AFinalModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$_init$8259983a10dc0bb0(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_TFinal$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFinalModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);
extern struct _jc_soot_jimple_parser_node_TFinal$object *_jc_soot_jimple_parser_node_AFinalModifier$method$getFinal$3c6746a37fdd7b7f(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$setFinal$b3afdb94fbbf804b(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_TFinal$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFinalModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$getFinal$3c6746a37fdd7b7f;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$setFinal$b3afdb94fbbf804b;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFinalModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);
	struct _jc_soot_jimple_parser_node_TFinal$object	*(*getFinal$3c6746a37fdd7b7f)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setFinal$b3afdb94fbbf804b)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_TFinal$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AFinalModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AFinalModifier$vmethods	soot_jimple_parser_node_AFinalModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFinalModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFinalModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFinalModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TFinal$object	*__5ffinal__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFinalModifier$refs {
    _jc_soot_jimple_parser_node_AFinalModifier$sub_refs	soot_jimple_parser_node_AFinalModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFinalModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs	soot_jimple_parser_node_AFinalModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFinalModifier$object {
	_jc_soot_jimple_parser_node_AFinalModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFinalModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFinalModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFinalModifier$vtype _jc_soot_jimple_parser_node_AFinalModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFinalModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFinalModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFinalModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AFinalModifier.h <==
// public final class soot.jimple.parser.node.AFinalModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f3c692663a8f388 soot_jimple_parser_node_AFinalModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AFinalModifier_H_
#define _JC_soot_jimple_parser_node_AFinalModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFinal$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$sub_refs	_jc_soot_jimple_parser_node_AFinalModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$refs	_jc_soot_jimple_parser_node_AFinalModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$nonrefs	_jc_soot_jimple_parser_node_AFinalModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFinalModifier$object	_jc_soot_jimple_parser_node_AFinalModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AFinalModifier$vmethods	_jc_soot_jimple_parser_node_AFinalModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFinalModifier$vtable	_jc_soot_jimple_parser_node_AFinalModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFinalModifier$vtype	_jc_soot_jimple_parser_node_AFinalModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$_init$8259983a10dc0bb0(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_TFinal$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFinalModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TFinal$object *_jc_soot_jimple_parser_node_AFinalModifier$method$getFinal$3c6746a37fdd7b7f(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFinalModifier$method$setFinal$b3afdb94fbbf804b(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_TFinal$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFinalModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$getFinal$3c6746a37fdd7b7f;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$setFinal$b3afdb94fbbf804b;
extern _jc_method _jc_soot_jimple_parser_node_AFinalModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFinalModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TFinal$object	*(*getFinal$3c6746a37fdd7b7f)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setFinal$b3afdb94fbbf804b)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *, struct _jc_soot_jimple_parser_node_TFinal$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFinalModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AFinalModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AFinalModifier$vmethods	soot_jimple_parser_node_AFinalModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFinalModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFinalModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFinalModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TFinal$object	*__5ffinal__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFinalModifier$refs {
    _jc_soot_jimple_parser_node_AFinalModifier$sub_refs	soot_jimple_parser_node_AFinalModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFinalModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AFinalModifier$sub_nonrefs	soot_jimple_parser_node_AFinalModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFinalModifier$object {
	_jc_soot_jimple_parser_node_AFinalModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFinalModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFinalModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFinalModifier$vtype _jc_soot_jimple_parser_node_AFinalModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFinalModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFinalModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFinalModifier_H_ */
